import { ThreeObject3d } from '@angular-three/core';
import { Directive, Input, NgModule } from '@angular/core';
import { AmbientLight, PointLight, DirectionalLight, SpotLight, HemisphereLight, RectAreaLight } from 'three';
import { CommonModule } from '@angular/common';

class ThreeLight extends ThreeObject3d {
    constructor() {
        super(...arguments);
        this._extraArgs = [];
    }
    set extraArgs(v) {
        this._extraArgs = v;
    }
    ngOnInit() {
        this.init();
    }
    initObject() {
        if (this.intensity) {
            this._extraArgs[1] = this.intensity;
        }
        this._light = new this.lightType(...this._extraArgs);
    }
    get object3d() {
        return this._light;
    }
}
ThreeLight.decorators = [
    { type: Directive }
];
ThreeLight.propDecorators = {
    intensity: [{ type: Input }]
};

class AmbientLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = AmbientLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
AmbientLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-ambientLight',
                exportAs: 'ngtAmbientLight',
                providers: [{ provide: ThreeObject3d, useExisting: AmbientLightDirective }],
            },] }
];
AmbientLightDirective.propDecorators = {
    args: [{ type: Input }]
};

class ThreeAmbientLightModule {
}
ThreeAmbientLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    AmbientLightDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    AmbientLightDirective
                ]
            },] }
];

class PointLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = PointLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
PointLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-pointLight',
                exportAs: 'ngtPointLight',
                providers: [{ provide: ThreeObject3d, useExisting: PointLightDirective }],
            },] }
];
PointLightDirective.propDecorators = {
    args: [{ type: Input }]
};

class ThreePointLightModule {
}
ThreePointLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [PointLightDirective],
                imports: [CommonModule],
                exports: [PointLightDirective],
            },] }
];

class DirectionalLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = DirectionalLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
DirectionalLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-directionalLight',
                exportAs: 'ngtDirectionalLight',
                providers: [
                    { provide: ThreeObject3d, useExisting: DirectionalLightDirective },
                ],
            },] }
];
DirectionalLightDirective.propDecorators = {
    args: [{ type: Input }]
};

class ThreeDirectionalLightModule {
}
ThreeDirectionalLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DirectionalLightDirective],
                imports: [CommonModule],
                exports: [DirectionalLightDirective],
            },] }
];

class SpotLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = SpotLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
SpotLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-spotLight',
                exportAs: 'ngtSpotLight',
                providers: [
                    { provide: ThreeObject3d, useExisting: SpotLightDirective },
                ],
            },] }
];
SpotLightDirective.propDecorators = {
    args: [{ type: Input }]
};

class ThreeSpotLightModule {
}
ThreeSpotLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SpotLightDirective],
                imports: [CommonModule],
                exports: [SpotLightDirective],
            },] }
];

class HemisphereLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = HemisphereLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
HemisphereLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-hemisphereLight',
                exportAs: 'ngtHemisphereLight',
                providers: [
                    { provide: ThreeObject3d, useExisting: HemisphereLightDirective },
                ],
            },] }
];
HemisphereLightDirective.propDecorators = {
    args: [{ type: Input }]
};

class HemisphereLightModule {
}
HemisphereLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [HemisphereLightDirective],
                imports: [CommonModule],
                exports: [HemisphereLightDirective],
            },] }
];

class RectAreaLightDirective extends ThreeLight {
    constructor() {
        super(...arguments);
        this.lightType = RectAreaLight;
    }
    set args(v) {
        this.extraArgs = v;
    }
}
RectAreaLightDirective.decorators = [
    { type: Directive, args: [{
                selector: 'ngt-rectAreaLight',
                exportAs: 'ngtRectAreaLight',
                providers: [{ provide: ThreeObject3d, useExisting: RectAreaLightDirective }],
            },] }
];
RectAreaLightDirective.propDecorators = {
    args: [{ type: Input }]
};

class RectAreaLightModule {
}
RectAreaLightModule.decorators = [
    { type: NgModule, args: [{
                declarations: [RectAreaLightDirective],
                imports: [CommonModule],
                exports: [RectAreaLightDirective],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { AmbientLightDirective, DirectionalLightDirective, HemisphereLightDirective, HemisphereLightModule, PointLightDirective, RectAreaLightDirective, RectAreaLightModule, SpotLightDirective, ThreeAmbientLightModule, ThreeDirectionalLightModule, ThreeLight, ThreePointLightModule, ThreeSpotLightModule };
//# sourceMappingURL=angular-three-core-lights.js.map
